producesUnordered function
Matches a Rill that emits the same elements as expected in any order.
expected may be a Dart Iterable or a RIterableOnce. The Rill must
succeed and contain exactly the same multiset of elements.
expect(Rill.emits([3, 1, 2]), producesUnordered([1, 2, 3]));
Implementation
Matcher producesUnordered(Object expected) => _ProducesUnordered(expected);