ribs_test_rill library

Test matchers for ribs_rill streams.

Provides producesError, producesInOrder, producesNothing, producesOnly, producesSameAs, and producesUnordered matchers.

Functions

producesError([Object? matcher]) → Matcher
Matches a Rill that fails with an error satisfying matcher.
producesInOrder(Object expected) → Matcher
Matches a Rill that emits elements in the exact order given by expected.
producesNothing() → Matcher
Matches a Rill that succeeds without emitting any elements.
producesOnly<A>(A a) → Matcher
Matches a Rill that emits exactly the single element a.
producesSameAs<A>(Rill<A> expected) → Matcher
Matches a Rill that produces the same outcome (success, error, or cancelation) and the same elements as expected.
producesUnordered(Object expected) → Matcher
Matches a Rill that emits the same elements as expected in any order.