isValidNel function
Returns a Matcher that matches a Valid value for a ValidatedNel.
If matcher is provided, the matched value inside Valid must also satisfy
it. If omitted, any Valid value matches.
Implementation
Matcher isValidNel([Object? matcher]) => _IsValid(matcher);