producesSameAs<A> function
Matcher
producesSameAs<A>(
- Rill<
A> expected
Matches a Rill that produces the same outcome (success, error, or
cancelation) and the same elements as expected.
Both rills are run to completion and their results compared.
expect(myRill, producesSameAs(Rill.emits([1, 2, 3])));
Implementation
Matcher producesSameAs<A>(Rill<A> expected) => _ProducesSameAs(expected);